@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::Plugin::Author::KENTNL::RecommendFixes;
 
-our $VERSION = '0.004000';
+our $VERSION = '0.004001';
 
 # ABSTRACT: Recommend generic changes to the dist.
 
@@ -382,6 +382,8 @@ lsub unrecommend => sub {
     qw( Class::Load ),                                       # Module::Runtime preferred
     qw( Readonly ),                                          # use Const::Fast
     qw( Sub::Name ),                                         # use Sub::Util
+    qw( autobox ),                                           # Rewrite it
+    qw( Moose::Autobox ),                                    # Rewrite it
   ];
 };
 
@@ -476,7 +478,7 @@ Dist::Zilla::Plugin::Author::KENTNL::RecommendFixes - Recommend generic changes
 
 =head1 VERSION
 
-version 0.004000
+version 0.004001
 
 =head1 DESCRIPTION
 
